@@ -23,6 +23,12 @@ class Enums:
     CONTENT_VIDEO = 'video/mp4'
     CONTENT_FILE = 'application/pdf'
     TYPE_FILE = ['png', 'gif', 'jpg', 'jpeg', 'mp4', 'pdf']
+    EMAIL = 'Correo'
+    CHAT = 'Chat'
+    SHARE_OPTIONS = [EMAIL, CHAT]
+    CONFIRMED = 'CONFIRMADO'
+    FORCE_CHANGE_PASSWORD = 'FORZAR_CAMBIO_CONTRASEÑA'
+    LIST_ACCOUNT_CONFIRMATION = [CONFIRMED, FORCE_CHANGE_PASSWORD]
 
 
 class Constants:
@@ -36,6 +42,7 @@ class Constants:
     FORMAT_DATE_TIME_TIMEZONE_EN = '%Y-%m-%dT%H:%M:%S.%fZ'
     EXPIRED = 'EXPIRADO'
     INVALID = 'INVALIDO'
+    PHOTO_DEFAULT = '3fa85f64-5717-4562-b3fc-2c963f66afa6'
 
 
 class FrontendUrl:
